@@ -5,7 +5,7 @@
 
     Additional docutils nodes.
 
-    :copyright: Copyright 2007-2017 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2018 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
@@ -49,6 +49,11 @@ class translatable(object):
         raise NotImplementedError
 
 
+class not_smartquotable(object):
+    """A node which does not support smart-quotes."""
+    support_smartquotes = False
+
+
 class toctree(nodes.General, nodes.Element, translatable):
     """Node for inserting a "TOC tree"."""
 
@@ -91,7 +96,7 @@ class desc_signature(nodes.Part, nodes.Inline, nodes.TextElement):
     """
 
 
-class desc_signature_line(nodes.Part, nodes.Inline, nodes.TextElement):
+class desc_signature_line(nodes.Part, nodes.Inline, nodes.FixedTextElement):
     """Node for a line in a multi-line object signatures.
 
     It should only be used in a ``desc_signature`` with ``is_multiline`` set.
@@ -101,7 +106,7 @@ class desc_signature_line(nodes.Part, nodes.Inline, nodes.TextElement):
 
 # nodes to use within a desc_signature or desc_signature_line
 
-class desc_addname(nodes.Part, nodes.Inline, nodes.TextElement):
+class desc_addname(nodes.Part, nodes.Inline, nodes.FixedTextElement):
     """Node for additional name parts (module name, class name)."""
 
 
@@ -109,7 +114,7 @@ class desc_addname(nodes.Part, nodes.Inline, nodes.TextElement):
 desc_classname = desc_addname
 
 
-class desc_type(nodes.Part, nodes.Inline, nodes.TextElement):
+class desc_type(nodes.Part, nodes.Inline, nodes.FixedTextElement):
     """Node for return types or object type names."""
 
 
@@ -120,20 +125,20 @@ class desc_returns(desc_type):
         return ' -> ' + nodes.TextElement.astext(self)
 
 
-class desc_name(nodes.Part, nodes.Inline, nodes.TextElement):
+class desc_name(nodes.Part, nodes.Inline, nodes.FixedTextElement):
     """Node for the main object name."""
 
 
-class desc_parameterlist(nodes.Part, nodes.Inline, nodes.TextElement):
+class desc_parameterlist(nodes.Part, nodes.Inline, nodes.FixedTextElement):
     """Node for a general parameter list."""
     child_text_separator = ', '
 
 
-class desc_parameter(nodes.Part, nodes.Inline, nodes.TextElement):
+class desc_parameter(nodes.Part, nodes.Inline, nodes.FixedTextElement):
     """Node for a single parameter."""
 
 
-class desc_optional(nodes.Part, nodes.Inline, nodes.TextElement):
+class desc_optional(nodes.Part, nodes.Inline, nodes.FixedTextElement):
     """Node for marking optional parts of the parameter list."""
     child_text_separator = ', '
 
@@ -142,7 +147,7 @@ class desc_optional(nodes.Part, nodes.Inline, nodes.TextElement):
         return '[' + nodes.TextElement.astext(self) + ']'
 
 
-class desc_annotation(nodes.Part, nodes.Inline, nodes.TextElement):
+class desc_annotation(nodes.Part, nodes.Inline, nodes.FixedTextElement):
     """Node for signature annotations (not Python 3-style annotations)."""
 
 
@@ -174,7 +179,7 @@ class productionlist(nodes.Admonition, nodes.Element):
     """
 
 
-class production(nodes.Part, nodes.Inline, nodes.TextElement):
+class production(nodes.Part, nodes.Inline, nodes.FixedTextElement):
     """Node for a single grammar production rule."""
 
 
@@ -266,13 +271,13 @@ class download_reference(nodes.reference):
     """Node for download references, similar to pending_xref."""
 
 
-class literal_emphasis(nodes.emphasis):
+class literal_emphasis(nodes.emphasis, not_smartquotable):
     """Node that behaves like `emphasis`, but further text processors are not
     applied (e.g. smartypants for HTML output).
     """
 
 
-class literal_strong(nodes.strong):
+class literal_strong(nodes.strong, not_smartquotable):
     """Node that behaves like `strong`, but further text processors are not
     applied (e.g. smartypants for HTML output).
     """
@@ -282,7 +287,7 @@ class abbreviation(nodes.Inline, nodes.TextElement):
     """Node for abbreviations with explanations."""
 
 
-class manpage(nodes.Inline, nodes.TextElement):
+class manpage(nodes.Inline, nodes.FixedTextElement):
     """Node for references to manpages."""
 
 
